import typing

import typing_extensions

_list = list

@typing.type_check_only
class AccessUrls(typing_extensions.TypedDict, total=False):
    caCertificateAccessUrl: str
    crlAccessUrls: _list[str]

@typing.type_check_only
class ActivateCertificateAuthorityRequest(typing_extensions.TypedDict, total=False):
    pemCaCertificate: str
    requestId: str
    subordinateConfig: SubordinateConfig

@typing.type_check_only
class AllowedKeyType(typing_extensions.TypedDict, total=False):
    ellipticCurve: EcKeyType
    rsa: RsaKeyType

@typing.type_check_only
class AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[AuditLogConfig]
    service: str

@typing.type_check_only
class AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class CaOptions(typing_extensions.TypedDict, total=False):
    isCa: bool
    maxIssuerPathLength: int

@typing.type_check_only
class CaPool(typing_extensions.TypedDict, total=False):
    issuancePolicy: IssuancePolicy
    labels: dict[str, typing.Any]
    name: str
    publishingOptions: PublishingOptions
    tier: typing_extensions.Literal["TIER_UNSPECIFIED", "ENTERPRISE", "DEVOPS"]

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class CertChain(typing_extensions.TypedDict, total=False):
    certificates: _list[str]

@typing.type_check_only
class Certificate(typing_extensions.TypedDict, total=False):
    certificateDescription: CertificateDescription
    certificateTemplate: str
    config: CertificateConfig
    createTime: str
    issuerCertificateAuthority: str
    labels: dict[str, typing.Any]
    lifetime: str
    name: str
    pemCertificate: str
    pemCertificateChain: _list[str]
    pemCsr: str
    revocationDetails: RevocationDetails
    subjectMode: typing_extensions.Literal[
        "SUBJECT_REQUEST_MODE_UNSPECIFIED", "DEFAULT", "REFLECTED_SPIFFE"
    ]
    updateTime: str

@typing.type_check_only
class CertificateAuthority(typing_extensions.TypedDict, total=False):
    accessUrls: AccessUrls
    caCertificateDescriptions: _list[CertificateDescription]
    config: CertificateConfig
    createTime: str
    deleteTime: str
    expireTime: str
    gcsBucket: str
    keySpec: KeyVersionSpec
    labels: dict[str, typing.Any]
    lifetime: str
    name: str
    pemCaCertificates: _list[str]
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "ENABLED",
        "DISABLED",
        "STAGED",
        "AWAITING_USER_ACTIVATION",
        "DELETED",
    ]
    subordinateConfig: SubordinateConfig
    tier: typing_extensions.Literal["TIER_UNSPECIFIED", "ENTERPRISE", "DEVOPS"]
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "SELF_SIGNED", "SUBORDINATE"]
    updateTime: str

@typing.type_check_only
class CertificateConfig(typing_extensions.TypedDict, total=False):
    publicKey: PublicKey
    subjectConfig: SubjectConfig
    x509Config: X509Parameters

@typing.type_check_only
class CertificateDescription(typing_extensions.TypedDict, total=False):
    aiaIssuingCertificateUrls: _list[str]
    authorityKeyId: KeyId
    certFingerprint: CertificateFingerprint
    crlDistributionPoints: _list[str]
    publicKey: PublicKey
    subjectDescription: SubjectDescription
    subjectKeyId: KeyId
    x509Description: X509Parameters

@typing.type_check_only
class CertificateExtensionConstraints(typing_extensions.TypedDict, total=False):
    additionalExtensions: _list[ObjectId]
    knownExtensions: _list[str]

@typing.type_check_only
class CertificateFingerprint(typing_extensions.TypedDict, total=False):
    sha256Hash: str

@typing.type_check_only
class CertificateIdentityConstraints(typing_extensions.TypedDict, total=False):
    allowSubjectAltNamesPassthrough: bool
    allowSubjectPassthrough: bool
    celExpression: Expr

@typing.type_check_only
class CertificateRevocationList(typing_extensions.TypedDict, total=False):
    accessUrl: str
    createTime: str
    labels: dict[str, typing.Any]
    name: str
    pemCrl: str
    revisionId: str
    revokedCertificates: _list[RevokedCertificate]
    sequenceNumber: str
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "ACTIVE", "SUPERSEDED"]
    updateTime: str

@typing.type_check_only
class CertificateTemplate(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    identityConstraints: CertificateIdentityConstraints
    labels: dict[str, typing.Any]
    name: str
    passthroughExtensions: CertificateExtensionConstraints
    predefinedValues: X509Parameters
    updateTime: str

@typing.type_check_only
class DisableCertificateAuthorityRequest(typing_extensions.TypedDict, total=False):
    requestId: str

@typing.type_check_only
class EcKeyType(typing_extensions.TypedDict, total=False):
    signatureAlgorithm: typing_extensions.Literal[
        "EC_SIGNATURE_ALGORITHM_UNSPECIFIED", "ECDSA_P256", "ECDSA_P384", "EDDSA_25519"
    ]

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class EnableCertificateAuthorityRequest(typing_extensions.TypedDict, total=False):
    requestId: str

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class ExtendedKeyUsageOptions(typing_extensions.TypedDict, total=False):
    clientAuth: bool
    codeSigning: bool
    emailProtection: bool
    ocspSigning: bool
    serverAuth: bool
    timeStamping: bool

@typing.type_check_only
class FetchCaCertsRequest(typing_extensions.TypedDict, total=False):
    requestId: str

@typing.type_check_only
class FetchCaCertsResponse(typing_extensions.TypedDict, total=False):
    caCerts: _list[CertChain]

@typing.type_check_only
class FetchCertificateAuthorityCsrResponse(typing_extensions.TypedDict, total=False):
    pemCsr: str

@typing.type_check_only
class IssuanceModes(typing_extensions.TypedDict, total=False):
    allowConfigBasedIssuance: bool
    allowCsrBasedIssuance: bool

@typing.type_check_only
class IssuancePolicy(typing_extensions.TypedDict, total=False):
    allowedIssuanceModes: IssuanceModes
    allowedKeyTypes: _list[AllowedKeyType]
    baselineValues: X509Parameters
    identityConstraints: CertificateIdentityConstraints
    maximumLifetime: str
    passthroughExtensions: CertificateExtensionConstraints

@typing.type_check_only
class KeyId(typing_extensions.TypedDict, total=False):
    keyId: str

@typing.type_check_only
class KeyUsage(typing_extensions.TypedDict, total=False):
    baseKeyUsage: KeyUsageOptions
    extendedKeyUsage: ExtendedKeyUsageOptions
    unknownExtendedKeyUsages: _list[ObjectId]

@typing.type_check_only
class KeyUsageOptions(typing_extensions.TypedDict, total=False):
    certSign: bool
    contentCommitment: bool
    crlSign: bool
    dataEncipherment: bool
    decipherOnly: bool
    digitalSignature: bool
    encipherOnly: bool
    keyAgreement: bool
    keyEncipherment: bool

@typing.type_check_only
class KeyVersionSpec(typing_extensions.TypedDict, total=False):
    algorithm: typing_extensions.Literal[
        "SIGN_HASH_ALGORITHM_UNSPECIFIED",
        "RSA_PSS_2048_SHA256",
        "RSA_PSS_3072_SHA256",
        "RSA_PSS_4096_SHA256",
        "RSA_PKCS1_2048_SHA256",
        "RSA_PKCS1_3072_SHA256",
        "RSA_PKCS1_4096_SHA256",
        "EC_P256_SHA256",
        "EC_P384_SHA384",
    ]
    cloudKmsKeyVersion: str

@typing.type_check_only
class ListCaPoolsResponse(typing_extensions.TypedDict, total=False):
    caPools: _list[CaPool]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListCertificateAuthoritiesResponse(typing_extensions.TypedDict, total=False):
    certificateAuthorities: _list[CertificateAuthority]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListCertificateRevocationListsResponse(typing_extensions.TypedDict, total=False):
    certificateRevocationLists: _list[CertificateRevocationList]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListCertificateTemplatesResponse(typing_extensions.TypedDict, total=False):
    certificateTemplates: _list[CertificateTemplate]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListCertificatesResponse(typing_extensions.TypedDict, total=False):
    certificates: _list[Certificate]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class ObjectId(typing_extensions.TypedDict, total=False):
    objectIdPath: _list[int]

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    apiVersion: str
    createTime: str
    endTime: str
    requestedCancellation: bool
    statusMessage: str
    target: str
    verb: str

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[AuditConfig]
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class PublicKey(typing_extensions.TypedDict, total=False):
    format: typing_extensions.Literal["KEY_FORMAT_UNSPECIFIED", "PEM"]
    key: str

@typing.type_check_only
class PublishingOptions(typing_extensions.TypedDict, total=False):
    publishCaCert: bool
    publishCrl: bool

@typing.type_check_only
class ReconciliationOperationMetadata(typing_extensions.TypedDict, total=False):
    deleteResource: bool
    exclusiveAction: typing_extensions.Literal[
        "UNKNOWN_REPAIR_ACTION", "DELETE", "RETRY"
    ]

@typing.type_check_only
class RevocationDetails(typing_extensions.TypedDict, total=False):
    revocationState: typing_extensions.Literal[
        "REVOCATION_REASON_UNSPECIFIED",
        "KEY_COMPROMISE",
        "CERTIFICATE_AUTHORITY_COMPROMISE",
        "AFFILIATION_CHANGED",
        "SUPERSEDED",
        "CESSATION_OF_OPERATION",
        "CERTIFICATE_HOLD",
        "PRIVILEGE_WITHDRAWN",
        "ATTRIBUTE_AUTHORITY_COMPROMISE",
    ]
    revocationTime: str

@typing.type_check_only
class RevokeCertificateRequest(typing_extensions.TypedDict, total=False):
    reason: typing_extensions.Literal[
        "REVOCATION_REASON_UNSPECIFIED",
        "KEY_COMPROMISE",
        "CERTIFICATE_AUTHORITY_COMPROMISE",
        "AFFILIATION_CHANGED",
        "SUPERSEDED",
        "CESSATION_OF_OPERATION",
        "CERTIFICATE_HOLD",
        "PRIVILEGE_WITHDRAWN",
        "ATTRIBUTE_AUTHORITY_COMPROMISE",
    ]
    requestId: str

@typing.type_check_only
class RevokedCertificate(typing_extensions.TypedDict, total=False):
    certificate: str
    hexSerialNumber: str
    revocationReason: typing_extensions.Literal[
        "REVOCATION_REASON_UNSPECIFIED",
        "KEY_COMPROMISE",
        "CERTIFICATE_AUTHORITY_COMPROMISE",
        "AFFILIATION_CHANGED",
        "SUPERSEDED",
        "CESSATION_OF_OPERATION",
        "CERTIFICATE_HOLD",
        "PRIVILEGE_WITHDRAWN",
        "ATTRIBUTE_AUTHORITY_COMPROMISE",
    ]

@typing.type_check_only
class RsaKeyType(typing_extensions.TypedDict, total=False):
    maxModulusSize: str
    minModulusSize: str

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy
    updateMask: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class Subject(typing_extensions.TypedDict, total=False):
    commonName: str
    countryCode: str
    locality: str
    organization: str
    organizationalUnit: str
    postalCode: str
    province: str
    streetAddress: str

@typing.type_check_only
class SubjectAltNames(typing_extensions.TypedDict, total=False):
    customSans: _list[X509Extension]
    dnsNames: _list[str]
    emailAddresses: _list[str]
    ipAddresses: _list[str]
    uris: _list[str]

@typing.type_check_only
class SubjectConfig(typing_extensions.TypedDict, total=False):
    subject: Subject
    subjectAltName: SubjectAltNames

@typing.type_check_only
class SubjectDescription(typing_extensions.TypedDict, total=False):
    hexSerialNumber: str
    lifetime: str
    notAfterTime: str
    notBeforeTime: str
    subject: Subject
    subjectAltName: SubjectAltNames

@typing.type_check_only
class SubordinateConfig(typing_extensions.TypedDict, total=False):
    certificateAuthority: str
    pemIssuerChain: SubordinateConfigChain

@typing.type_check_only
class SubordinateConfigChain(typing_extensions.TypedDict, total=False):
    pemCertificates: _list[str]

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class UndeleteCertificateAuthorityRequest(typing_extensions.TypedDict, total=False):
    requestId: str

@typing.type_check_only
class X509Extension(typing_extensions.TypedDict, total=False):
    critical: bool
    objectId: ObjectId
    value: str

@typing.type_check_only
class X509Parameters(typing_extensions.TypedDict, total=False):
    additionalExtensions: _list[X509Extension]
    aiaOcspServers: _list[str]
    caOptions: CaOptions
    keyUsage: KeyUsage
    policyIds: _list[ObjectId]



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Account(typing_extensions.TypedDict, total=False):
    childLink: dict[str, typing.Any]
    created: str
    id: str
    kind: str
    name: str
    permissions: dict[str, typing.Any]
    selfLink: str
    starred: bool
    updated: str

@typing.type_check_only
class AccountRef(typing_extensions.TypedDict, total=False):
    href: str
    id: str
    kind: str
    name: str

@typing.type_check_only
class AccountSummaries(typing_extensions.TypedDict, total=False):
    items: _list[AccountSummary]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int
    username: str

@typing.type_check_only
class AccountSummary(typing_extensions.TypedDict, total=False):
    id: str
    kind: str
    name: str
    starred: bool
    webProperties: _list[WebPropertySummary]

@typing.type_check_only
class AccountTicket(typing_extensions.TypedDict, total=False):
    account: Account
    id: str
    kind: str
    profile: Profile
    redirectUri: str
    webproperty: Webproperty

@typing.type_check_only
class AccountTreeRequest(typing_extensions.TypedDict, total=False):
    accountName: str
    kind: str
    profileName: str
    timezone: str
    webpropertyName: str
    websiteUrl: str

@typing.type_check_only
class AccountTreeResponse(typing_extensions.TypedDict, total=False):
    account: Account
    kind: str
    profile: Profile
    webproperty: Webproperty

@typing.type_check_only
class Accounts(typing_extensions.TypedDict, total=False):
    items: _list[Account]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int
    username: str

@typing.type_check_only
class AdWordsAccount(typing_extensions.TypedDict, total=False):
    autoTaggingEnabled: bool
    customerId: str
    kind: str

@typing.type_check_only
class AnalyticsDataimportDeleteUploadDataRequest(
    typing_extensions.TypedDict, total=False
):
    customDataImportUids: _list[str]

@typing.type_check_only
class Column(typing_extensions.TypedDict, total=False):
    attributes: dict[str, typing.Any]
    id: str
    kind: str

@typing.type_check_only
class Columns(typing_extensions.TypedDict, total=False):
    attributeNames: _list[str]
    etag: str
    items: _list[Column]
    kind: str
    totalResults: int

@typing.type_check_only
class CustomDataSource(typing_extensions.TypedDict, total=False):
    accountId: str
    childLink: dict[str, typing.Any]
    created: str
    description: str
    id: str
    importBehavior: str
    kind: str
    name: str
    parentLink: dict[str, typing.Any]
    profilesLinked: _list[str]
    schema: _list[str]
    selfLink: str
    type: str
    updated: str
    uploadType: str
    webPropertyId: str

@typing.type_check_only
class CustomDataSources(typing_extensions.TypedDict, total=False):
    items: _list[CustomDataSource]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int
    username: str

@typing.type_check_only
class CustomDimension(typing_extensions.TypedDict, total=False):
    accountId: str
    active: bool
    created: str
    id: str
    index: int
    kind: str
    name: str
    parentLink: dict[str, typing.Any]
    scope: str
    selfLink: str
    updated: str
    webPropertyId: str

@typing.type_check_only
class CustomDimensions(typing_extensions.TypedDict, total=False):
    items: _list[CustomDimension]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int
    username: str

@typing.type_check_only
class CustomMetric(typing_extensions.TypedDict, total=False):
    accountId: str
    active: bool
    created: str
    id: str
    index: int
    kind: str
    max_value: str
    min_value: str
    name: str
    parentLink: dict[str, typing.Any]
    scope: str
    selfLink: str
    type: str
    updated: str
    webPropertyId: str

@typing.type_check_only
class CustomMetrics(typing_extensions.TypedDict, total=False):
    items: _list[CustomMetric]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int
    username: str

@typing.type_check_only
class EntityAdWordsLink(typing_extensions.TypedDict, total=False):
    adWordsAccounts: _list[AdWordsAccount]
    entity: dict[str, typing.Any]
    id: str
    kind: str
    name: str
    profileIds: _list[str]
    selfLink: str

@typing.type_check_only
class EntityAdWordsLinks(typing_extensions.TypedDict, total=False):
    items: _list[EntityAdWordsLink]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int

@typing.type_check_only
class EntityUserLink(typing_extensions.TypedDict, total=False):
    entity: dict[str, typing.Any]
    id: str
    kind: str
    permissions: dict[str, typing.Any]
    selfLink: str
    userRef: UserRef

@typing.type_check_only
class EntityUserLinks(typing_extensions.TypedDict, total=False):
    items: _list[EntityUserLink]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int

@typing.type_check_only
class Experiment(typing_extensions.TypedDict, total=False):
    accountId: str
    created: str
    description: str
    editableInGaUi: bool
    endTime: str
    equalWeighting: bool
    id: str
    internalWebPropertyId: str
    kind: str
    minimumExperimentLengthInDays: int
    name: str
    objectiveMetric: str
    optimizationType: str
    parentLink: dict[str, typing.Any]
    profileId: str
    reasonExperimentEnded: str
    rewriteVariationUrlsAsOriginal: bool
    selfLink: str
    servingFramework: str
    snippet: str
    startTime: str
    status: str
    trafficCoverage: float
    updated: str
    variations: _list[dict[str, typing.Any]]
    webPropertyId: str
    winnerConfidenceLevel: float
    winnerFound: bool

@typing.type_check_only
class Experiments(typing_extensions.TypedDict, total=False):
    items: _list[Experiment]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int
    username: str

@typing.type_check_only
class Filter(typing_extensions.TypedDict, total=False):
    accountId: str
    advancedDetails: dict[str, typing.Any]
    created: str
    excludeDetails: FilterExpression
    id: str
    includeDetails: FilterExpression
    kind: str
    lowercaseDetails: dict[str, typing.Any]
    name: str
    parentLink: dict[str, typing.Any]
    searchAndReplaceDetails: dict[str, typing.Any]
    selfLink: str
    type: str
    updated: str
    uppercaseDetails: dict[str, typing.Any]

@typing.type_check_only
class FilterExpression(typing_extensions.TypedDict, total=False):
    caseSensitive: bool
    expressionValue: str
    field: str
    fieldIndex: int
    kind: str
    matchType: str

@typing.type_check_only
class FilterRef(typing_extensions.TypedDict, total=False):
    accountId: str
    href: str
    id: str
    kind: str
    name: str

@typing.type_check_only
class Filters(typing_extensions.TypedDict, total=False):
    items: _list[Filter]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int
    username: str

@typing.type_check_only
class GaData(typing_extensions.TypedDict, total=False):
    columnHeaders: _list[dict[str, typing.Any]]
    containsSampledData: bool
    dataLastRefreshed: str
    dataTable: dict[str, typing.Any]
    id: str
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    profileInfo: dict[str, typing.Any]
    query: dict[str, typing.Any]
    rows: _list[list]
    sampleSize: str
    sampleSpace: str
    selfLink: str
    totalResults: int
    totalsForAllResults: dict[str, typing.Any]

@typing.type_check_only
class Goal(typing_extensions.TypedDict, total=False):
    accountId: str
    active: bool
    created: str
    eventDetails: dict[str, typing.Any]
    id: str
    internalWebPropertyId: str
    kind: str
    name: str
    parentLink: dict[str, typing.Any]
    profileId: str
    selfLink: str
    type: str
    updated: str
    urlDestinationDetails: dict[str, typing.Any]
    value: float
    visitNumPagesDetails: dict[str, typing.Any]
    visitTimeOnSiteDetails: dict[str, typing.Any]
    webPropertyId: str

@typing.type_check_only
class Goals(typing_extensions.TypedDict, total=False):
    items: _list[Goal]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int
    username: str

@typing.type_check_only
class HashClientIdRequest(typing_extensions.TypedDict, total=False):
    clientId: str
    kind: str
    webPropertyId: str

@typing.type_check_only
class HashClientIdResponse(typing_extensions.TypedDict, total=False):
    clientId: str
    hashedClientId: str
    kind: str
    webPropertyId: str

@typing.type_check_only
class IncludeConditions(typing_extensions.TypedDict, total=False):
    daysToLookBack: int
    isSmartList: bool
    kind: str
    membershipDurationDays: int
    segment: str

@typing.type_check_only
class LinkedForeignAccount(typing_extensions.TypedDict, total=False):
    accountId: str
    eligibleForSearch: bool
    id: str
    internalWebPropertyId: str
    kind: str
    linkedAccountId: str
    remarketingAudienceId: str
    status: str
    type: str
    webPropertyId: str

@typing.type_check_only
class McfData(typing_extensions.TypedDict, total=False):
    columnHeaders: _list[dict[str, typing.Any]]
    containsSampledData: bool
    id: str
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    profileInfo: dict[str, typing.Any]
    query: dict[str, typing.Any]
    rows: _list[list]
    sampleSize: str
    sampleSpace: str
    selfLink: str
    totalResults: int
    totalsForAllResults: dict[str, typing.Any]

@typing.type_check_only
class Profile(typing_extensions.TypedDict, total=False):
    accountId: str
    botFilteringEnabled: bool
    childLink: dict[str, typing.Any]
    created: str
    currency: str
    defaultPage: str
    eCommerceTracking: bool
    enhancedECommerceTracking: bool
    excludeQueryParameters: str
    id: str
    internalWebPropertyId: str
    kind: str
    name: str
    parentLink: dict[str, typing.Any]
    permissions: dict[str, typing.Any]
    selfLink: str
    siteSearchCategoryParameters: str
    siteSearchQueryParameters: str
    starred: bool
    stripSiteSearchCategoryParameters: bool
    stripSiteSearchQueryParameters: bool
    timezone: str
    type: str
    updated: str
    webPropertyId: str
    websiteUrl: str

@typing.type_check_only
class ProfileFilterLink(typing_extensions.TypedDict, total=False):
    filterRef: FilterRef
    id: str
    kind: str
    profileRef: ProfileRef
    rank: int
    selfLink: str

@typing.type_check_only
class ProfileFilterLinks(typing_extensions.TypedDict, total=False):
    items: _list[ProfileFilterLink]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int
    username: str

@typing.type_check_only
class ProfileRef(typing_extensions.TypedDict, total=False):
    accountId: str
    href: str
    id: str
    internalWebPropertyId: str
    kind: str
    name: str
    webPropertyId: str

@typing.type_check_only
class ProfileSummary(typing_extensions.TypedDict, total=False):
    id: str
    kind: str
    name: str
    starred: bool
    type: str

@typing.type_check_only
class Profiles(typing_extensions.TypedDict, total=False):
    items: _list[Profile]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int
    username: str

@typing.type_check_only
class RealtimeData(typing_extensions.TypedDict, total=False):
    columnHeaders: _list[dict[str, typing.Any]]
    id: str
    kind: str
    profileInfo: dict[str, typing.Any]
    query: dict[str, typing.Any]
    rows: _list[list]
    selfLink: str
    totalResults: int
    totalsForAllResults: dict[str, typing.Any]

@typing.type_check_only
class RemarketingAudience(typing_extensions.TypedDict, total=False):
    accountId: str
    audienceDefinition: dict[str, typing.Any]
    audienceType: str
    created: str
    description: str
    id: str
    internalWebPropertyId: str
    kind: str
    linkedAdAccounts: _list[LinkedForeignAccount]
    linkedViews: _list[str]
    name: str
    stateBasedAudienceDefinition: dict[str, typing.Any]
    updated: str
    webPropertyId: str

@typing.type_check_only
class RemarketingAudiences(typing_extensions.TypedDict, total=False):
    items: _list[RemarketingAudience]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int
    username: str

@typing.type_check_only
class Segment(typing_extensions.TypedDict, total=False):
    created: str
    definition: str
    id: str
    kind: str
    name: str
    segmentId: str
    selfLink: str
    type: str
    updated: str

@typing.type_check_only
class Segments(typing_extensions.TypedDict, total=False):
    items: _list[Segment]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int
    username: str

AlternativeUnsampledReport = typing_extensions.TypedDict(
    "AlternativeUnsampledReport",
    {
        "accountId": str,
        "cloudStorageDownloadDetails": dict[str, typing.Any],
        "created": str,
        "dimensions": str,
        "downloadType": str,
        "driveDownloadDetails": dict[str, typing.Any],
        "end-date": str,
        "filters": str,
        "id": str,
        "kind": str,
        "metrics": str,
        "profileId": str,
        "segment": str,
        "selfLink": str,
        "start-date": str,
        "status": str,
        "title": str,
        "updated": str,
        "webPropertyId": str,
    },
    total=False,
)

@typing.type_check_only
class UnsampledReport(AlternativeUnsampledReport): ...

@typing.type_check_only
class UnsampledReports(typing_extensions.TypedDict, total=False):
    items: _list[UnsampledReport]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int
    username: str

@typing.type_check_only
class Upload(typing_extensions.TypedDict, total=False):
    accountId: str
    customDataSourceId: str
    errors: _list[str]
    id: str
    kind: str
    status: str
    uploadTime: str

@typing.type_check_only
class Uploads(typing_extensions.TypedDict, total=False):
    items: _list[Upload]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int

@typing.type_check_only
class UserDeletionRequest(typing_extensions.TypedDict, total=False):
    deletionRequestTime: str
    firebaseProjectId: str
    id: dict[str, typing.Any]
    kind: str
    propertyId: str
    webPropertyId: str

@typing.type_check_only
class UserRef(typing_extensions.TypedDict, total=False):
    email: str
    id: str
    kind: str

@typing.type_check_only
class WebPropertyRef(typing_extensions.TypedDict, total=False):
    accountId: str
    href: str
    id: str
    internalWebPropertyId: str
    kind: str
    name: str

@typing.type_check_only
class WebPropertySummary(typing_extensions.TypedDict, total=False):
    id: str
    internalWebPropertyId: str
    kind: str
    level: str
    name: str
    profiles: _list[ProfileSummary]
    starred: bool
    websiteUrl: str

@typing.type_check_only
class Webproperties(typing_extensions.TypedDict, total=False):
    items: _list[Webproperty]
    itemsPerPage: int
    kind: str
    nextLink: str
    previousLink: str
    startIndex: int
    totalResults: int
    username: str

@typing.type_check_only
class Webproperty(typing_extensions.TypedDict, total=False):
    accountId: str
    childLink: dict[str, typing.Any]
    created: str
    dataRetentionResetOnNewActivity: bool
    dataRetentionTtl: str
    defaultProfileId: str
    id: str
    industryVertical: str
    internalWebPropertyId: str
    kind: str
    level: str
    name: str
    parentLink: dict[str, typing.Any]
    permissions: dict[str, typing.Any]
    profileCount: int
    selfLink: str
    starred: bool
    updated: str
    websiteUrl: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AccountActivity(typing_extensions.TypedDict, total=False):
    activityLevel: typing_extensions.Literal[
        "ACTIVITY_LEVEL_UNSPECIFIED",
        "UNEVALUATED",
        "UNUSUAL",
        "UNKNOWN",
        "TYPICAL_BASIC",
        "TYPICAL_STRONG",
    ]

@typing.type_check_only
class AccountDetails(typing_extensions.TypedDict, total=False):
    accountActivity: AccountActivity
    accountRiskVerdict: AccountRiskVerdict
    appLicensingVerdict: typing_extensions.Literal[
        "UNKNOWN", "LICENSED", "UNLICENSED", "UNEVALUATED"
    ]

@typing.type_check_only
class AccountRiskVerdict(typing_extensions.TypedDict, total=False):
    risk: typing_extensions.Literal[
        "RISK_UNSPECIFIED", "UNEVALUATED", "HIGHER", "UNKNOWN", "LOWER", "LOWEST"
    ]
    riskLevel: typing_extensions.Literal[
        "RISK_LEVEL_UNSPECIFIED",
        "RISK_LEVEL_UNEVALUATED",
        "RISK_LEVEL_RISK",
        "RISK_LEVEL_UNKNOWN",
        "RISK_LEVEL_LOW_RISK",
        "RISK_LEVEL_LOWEST_RISK",
    ]

@typing.type_check_only
class AppIntegrity(typing_extensions.TypedDict, total=False):
    appRecognitionVerdict: typing_extensions.Literal[
        "UNKNOWN", "PLAY_RECOGNIZED", "UNRECOGNIZED_VERSION", "UNEVALUATED"
    ]
    certificateSha256Digest: _list[str]
    packageName: str
    versionCode: str

@typing.type_check_only
class DecodeIntegrityTokenRequest(typing_extensions.TypedDict, total=False):
    integrityToken: str

@typing.type_check_only
class DecodeIntegrityTokenResponse(typing_extensions.TypedDict, total=False):
    tokenPayloadExternal: TokenPayloadExternal

@typing.type_check_only
class DeviceIntegrity(typing_extensions.TypedDict, total=False):
    deviceRecognitionVerdict: _list[str]

@typing.type_check_only
class RequestDetails(typing_extensions.TypedDict, total=False):
    nonce: str
    requestPackageName: str
    timestampMillis: str

@typing.type_check_only
class TestingDetails(typing_extensions.TypedDict, total=False):
    isTestingResponse: bool

@typing.type_check_only
class TokenPayloadExternal(typing_extensions.TypedDict, total=False):
    accountDetails: AccountDetails
    appIntegrity: AppIntegrity
    deviceIntegrity: DeviceIntegrity
    requestDetails: RequestDetails
    testingDetails: TestingDetails



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleCloudDatapipelinesV1DataflowJobDetails(
    typing_extensions.TypedDict, total=False
):
    currentWorkers: int
    resourceInfo: dict[str, typing.Any]
    sdkVersion: GoogleCloudDatapipelinesV1SdkVersion

@typing.type_check_only
class GoogleCloudDatapipelinesV1FlexTemplateRuntimeEnvironment(
    typing_extensions.TypedDict, total=False
):
    additionalExperiments: _list[str]
    additionalUserLabels: dict[str, typing.Any]
    enableStreamingEngine: bool
    flexrsGoal: typing_extensions.Literal[
        "FLEXRS_UNSPECIFIED", "FLEXRS_SPEED_OPTIMIZED", "FLEXRS_COST_OPTIMIZED"
    ]
    ipConfiguration: typing_extensions.Literal[
        "WORKER_IP_UNSPECIFIED", "WORKER_IP_PUBLIC", "WORKER_IP_PRIVATE"
    ]
    kmsKeyName: str
    machineType: str
    maxWorkers: int
    network: str
    numWorkers: int
    serviceAccountEmail: str
    subnetwork: str
    tempLocation: str
    workerRegion: str
    workerZone: str
    zone: str

@typing.type_check_only
class GoogleCloudDatapipelinesV1Job(typing_extensions.TypedDict, total=False):
    createTime: str
    dataflowJobDetails: GoogleCloudDatapipelinesV1DataflowJobDetails
    endTime: str
    id: str
    name: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "STATE_PENDING",
        "STATE_RUNNING",
        "STATE_DONE",
        "STATE_FAILED",
        "STATE_CANCELLED",
    ]
    status: GoogleRpcStatus

@typing.type_check_only
class GoogleCloudDatapipelinesV1LaunchFlexTemplateParameter(
    typing_extensions.TypedDict, total=False
):
    containerSpecGcsPath: str
    environment: GoogleCloudDatapipelinesV1FlexTemplateRuntimeEnvironment
    jobName: str
    launchOptions: dict[str, typing.Any]
    parameters: dict[str, typing.Any]
    transformNameMappings: dict[str, typing.Any]
    update: bool

@typing.type_check_only
class GoogleCloudDatapipelinesV1LaunchFlexTemplateRequest(
    typing_extensions.TypedDict, total=False
):
    launchParameter: GoogleCloudDatapipelinesV1LaunchFlexTemplateParameter
    location: str
    projectId: str
    validateOnly: bool

@typing.type_check_only
class GoogleCloudDatapipelinesV1LaunchTemplateParameters(
    typing_extensions.TypedDict, total=False
):
    environment: GoogleCloudDatapipelinesV1RuntimeEnvironment
    jobName: str
    parameters: dict[str, typing.Any]
    transformNameMapping: dict[str, typing.Any]
    update: bool

@typing.type_check_only
class GoogleCloudDatapipelinesV1LaunchTemplateRequest(
    typing_extensions.TypedDict, total=False
):
    gcsPath: str
    launchParameters: GoogleCloudDatapipelinesV1LaunchTemplateParameters
    location: str
    projectId: str
    validateOnly: bool

@typing.type_check_only
class GoogleCloudDatapipelinesV1ListJobsResponse(
    typing_extensions.TypedDict, total=False
):
    jobs: _list[GoogleCloudDatapipelinesV1Job]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDatapipelinesV1ListPipelinesResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    pipelines: _list[GoogleCloudDatapipelinesV1Pipeline]

@typing.type_check_only
class GoogleCloudDatapipelinesV1Pipeline(typing_extensions.TypedDict, total=False):
    createTime: str
    displayName: str
    jobCount: int
    lastUpdateTime: str
    name: str
    pipelineSources: dict[str, typing.Any]
    scheduleInfo: GoogleCloudDatapipelinesV1ScheduleSpec
    schedulerServiceAccountEmail: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "STATE_RESUMING",
        "STATE_ACTIVE",
        "STATE_STOPPING",
        "STATE_ARCHIVED",
        "STATE_PAUSED",
    ]
    type: typing_extensions.Literal[
        "PIPELINE_TYPE_UNSPECIFIED", "PIPELINE_TYPE_BATCH", "PIPELINE_TYPE_STREAMING"
    ]
    workload: GoogleCloudDatapipelinesV1Workload

@typing.type_check_only
class GoogleCloudDatapipelinesV1RunPipelineRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDatapipelinesV1RunPipelineResponse(
    typing_extensions.TypedDict, total=False
):
    job: GoogleCloudDatapipelinesV1Job

@typing.type_check_only
class GoogleCloudDatapipelinesV1RuntimeEnvironment(
    typing_extensions.TypedDict, total=False
):
    additionalExperiments: _list[str]
    additionalUserLabels: dict[str, typing.Any]
    bypassTempDirValidation: bool
    enableStreamingEngine: bool
    ipConfiguration: typing_extensions.Literal[
        "WORKER_IP_UNSPECIFIED", "WORKER_IP_PUBLIC", "WORKER_IP_PRIVATE"
    ]
    kmsKeyName: str
    machineType: str
    maxWorkers: int
    network: str
    numWorkers: int
    serviceAccountEmail: str
    subnetwork: str
    tempLocation: str
    workerRegion: str
    workerZone: str
    zone: str

@typing.type_check_only
class GoogleCloudDatapipelinesV1ScheduleSpec(typing_extensions.TypedDict, total=False):
    nextJobTime: str
    schedule: str
    timeZone: str

@typing.type_check_only
class GoogleCloudDatapipelinesV1SdkVersion(typing_extensions.TypedDict, total=False):
    sdkSupportStatus: typing_extensions.Literal[
        "UNKNOWN", "SUPPORTED", "STALE", "DEPRECATED", "UNSUPPORTED"
    ]
    version: str
    versionDisplayName: str

@typing.type_check_only
class GoogleCloudDatapipelinesV1StopPipelineRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDatapipelinesV1Workload(typing_extensions.TypedDict, total=False):
    dataflowFlexTemplateRequest: GoogleCloudDatapipelinesV1LaunchFlexTemplateRequest
    dataflowLaunchTemplateRequest: GoogleCloudDatapipelinesV1LaunchTemplateRequest

@typing.type_check_only
class GoogleProtobufEmpty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GoogleRpcStatus(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class RecommendationsAIResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class CatalogsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class CatalogItemsResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: GoogleCloudRecommendationengineV1beta1CatalogItem = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudRecommendationengineV1beta1CatalogItemHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> GoogleProtobufEmptyHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> GoogleCloudRecommendationengineV1beta1CatalogItemHttpRequest: ...
                    def import_(
                        self,
                        *,
                        parent: str,
                        body: GoogleCloudRecommendationengineV1beta1ImportCatalogItemsRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleLongrunningOperationHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudRecommendationengineV1beta1ListCatalogItemsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: GoogleCloudRecommendationengineV1beta1ListCatalogItemsResponseHttpRequest,
                        previous_response: GoogleCloudRecommendationengineV1beta1ListCatalogItemsResponse,
                    ) -> GoogleCloudRecommendationengineV1beta1ListCatalogItemsResponseHttpRequest | None: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudRecommendationengineV1beta1CatalogItem = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudRecommendationengineV1beta1CatalogItemHttpRequest: ...

                @typing.type_check_only
                class EventStoresResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class OperationsResource(googleapiclient.discovery.Resource):
                        def get(
                            self, *, name: str, **kwargs: typing.Any
                        ) -> GoogleLongrunningOperationHttpRequest: ...
                        def list(
                            self,
                            *,
                            name: str,
                            filter: str = ...,
                            pageSize: int = ...,
                            pageToken: str = ...,
                            **kwargs: typing.Any
                        ) -> GoogleLongrunningListOperationsResponseHttpRequest: ...
                        def list_next(
                            self,
                            previous_request: GoogleLongrunningListOperationsResponseHttpRequest,
                            previous_response: GoogleLongrunningListOperationsResponse,
                        ) -> GoogleLongrunningListOperationsResponseHttpRequest | None: ...

                    @typing.type_check_only
                    class PlacementsResource(googleapiclient.discovery.Resource):
                        def predict(
                            self,
                            *,
                            name: str,
                            body: GoogleCloudRecommendationengineV1beta1PredictRequest = ...,
                            **kwargs: typing.Any
                        ) -> GoogleCloudRecommendationengineV1beta1PredictResponseHttpRequest: ...
                        def predict_next(
                            self,
                            previous_request: GoogleCloudRecommendationengineV1beta1PredictResponseHttpRequest,
                            previous_response: GoogleCloudRecommendationengineV1beta1PredictResponse,
                        ) -> GoogleCloudRecommendationengineV1beta1PredictResponseHttpRequest | None: ...

                    @typing.type_check_only
                    class PredictionApiKeyRegistrationsResource(
                        googleapiclient.discovery.Resource
                    ):
                        def create(
                            self,
                            *,
                            parent: str,
                            body: GoogleCloudRecommendationengineV1beta1CreatePredictionApiKeyRegistrationRequest = ...,
                            **kwargs: typing.Any
                        ) -> GoogleCloudRecommendationengineV1beta1PredictionApiKeyRegistrationHttpRequest: ...
                        def delete(
                            self, *, name: str, **kwargs: typing.Any
                        ) -> GoogleProtobufEmptyHttpRequest: ...
                        def list(
                            self,
                            *,
                            parent: str,
                            pageSize: int = ...,
                            pageToken: str = ...,
                            **kwargs: typing.Any
                        ) -> GoogleCloudRecommendationengineV1beta1ListPredictionApiKeyRegistrationsResponseHttpRequest: ...
                        def list_next(
                            self,
                            previous_request: GoogleCloudRecommendationengineV1beta1ListPredictionApiKeyRegistrationsResponseHttpRequest,
                            previous_response: GoogleCloudRecommendationengineV1beta1ListPredictionApiKeyRegistrationsResponse,
                        ) -> GoogleCloudRecommendationengineV1beta1ListPredictionApiKeyRegistrationsResponseHttpRequest | None: ...

                    @typing.type_check_only
                    class UserEventsResource(googleapiclient.discovery.Resource):
                        def collect(
                            self,
                            *,
                            parent: str,
                            ets: str = ...,
                            uri: str = ...,
                            userEvent: str = ...,
                            **kwargs: typing.Any
                        ) -> GoogleApiHttpBodyHttpRequest: ...
                        def import_(
                            self,
                            *,
                            parent: str,
                            body: GoogleCloudRecommendationengineV1beta1ImportUserEventsRequest = ...,
                            **kwargs: typing.Any
                        ) -> GoogleLongrunningOperationHttpRequest: ...
                        def list(
                            self,
                            *,
                            parent: str,
                            filter: str = ...,
                            pageSize: int = ...,
                            pageToken: str = ...,
                            **kwargs: typing.Any
                        ) -> GoogleCloudRecommendationengineV1beta1ListUserEventsResponseHttpRequest: ...
                        def list_next(
                            self,
                            previous_request: GoogleCloudRecommendationengineV1beta1ListUserEventsResponseHttpRequest,
                            previous_response: GoogleCloudRecommendationengineV1beta1ListUserEventsResponse,
                        ) -> GoogleCloudRecommendationengineV1beta1ListUserEventsResponseHttpRequest | None: ...
                        def purge(
                            self,
                            *,
                            parent: str,
                            body: GoogleCloudRecommendationengineV1beta1PurgeUserEventsRequest = ...,
                            **kwargs: typing.Any
                        ) -> GoogleLongrunningOperationHttpRequest: ...
                        def rejoin(
                            self,
                            *,
                            parent: str,
                            body: GoogleCloudRecommendationengineV1beta1RejoinUserEventsRequest = ...,
                            **kwargs: typing.Any
                        ) -> GoogleLongrunningOperationHttpRequest: ...
                        def write(
                            self,
                            *,
                            parent: str,
                            body: GoogleCloudRecommendationengineV1beta1UserEvent = ...,
                            **kwargs: typing.Any
                        ) -> GoogleCloudRecommendationengineV1beta1UserEventHttpRequest: ...

                    def operations(self) -> OperationsResource: ...
                    def placements(self) -> PlacementsResource: ...
                    def predictionApiKeyRegistrations(
                        self,
                    ) -> PredictionApiKeyRegistrationsResource: ...
                    def userEvents(self) -> UserEventsResource: ...

                @typing.type_check_only
                class OperationsResource(googleapiclient.discovery.Resource):
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> GoogleLongrunningOperationHttpRequest: ...
                    def list(
                        self,
                        *,
                        name: str,
                        filter: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleLongrunningListOperationsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: GoogleLongrunningListOperationsResponseHttpRequest,
                        previous_response: GoogleLongrunningListOperationsResponse,
                    ) -> GoogleLongrunningListOperationsResponseHttpRequest | None: ...

                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudRecommendationengineV1beta1ListCatalogsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudRecommendationengineV1beta1ListCatalogsResponseHttpRequest,
                    previous_response: GoogleCloudRecommendationengineV1beta1ListCatalogsResponse,
                ) -> GoogleCloudRecommendationengineV1beta1ListCatalogsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudRecommendationengineV1beta1Catalog = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudRecommendationengineV1beta1CatalogHttpRequest: ...
                def catalogItems(self) -> CatalogItemsResource: ...
                def eventStores(self) -> EventStoresResource: ...
                def operations(self) -> OperationsResource: ...

            def catalogs(self) -> CatalogsResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class GoogleApiHttpBodyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleApiHttpBody: ...

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1CatalogHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecommendationengineV1beta1Catalog: ...

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1CatalogItemHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecommendationengineV1beta1CatalogItem: ...

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ListCatalogItemsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecommendationengineV1beta1ListCatalogItemsResponse: ...

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ListCatalogsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecommendationengineV1beta1ListCatalogsResponse: ...

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ListPredictionApiKeyRegistrationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecommendationengineV1beta1ListPredictionApiKeyRegistrationsResponse: ...

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ListUserEventsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecommendationengineV1beta1ListUserEventsResponse: ...

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1PredictResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecommendationengineV1beta1PredictResponse: ...

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1PredictionApiKeyRegistrationHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecommendationengineV1beta1PredictionApiKeyRegistration: ...

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1UserEventHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecommendationengineV1beta1UserEvent: ...

@typing.type_check_only
class GoogleLongrunningListOperationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningListOperationsResponse: ...

@typing.type_check_only
class GoogleLongrunningOperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningOperation: ...

@typing.type_check_only
class GoogleProtobufEmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleProtobufEmpty: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Arg(typing_extensions.TypedDict, total=False):
    anyValue: Empty
    exactValue: typing.Any

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ExpressionReport(typing_extensions.TypedDict, total=False):
    children: _list[ExpressionReport]
    sourcePosition: SourcePosition
    values: _list[ValueCount]

@typing.type_check_only
class File(typing_extensions.TypedDict, total=False):
    content: str
    fingerprint: str
    name: str

@typing.type_check_only
class FunctionCall(typing_extensions.TypedDict, total=False):
    args: _list[typing.Any]
    function: str

@typing.type_check_only
class FunctionMock(typing_extensions.TypedDict, total=False):
    args: _list[Arg]
    function: str
    result: Result

@typing.type_check_only
class GetReleaseExecutableResponse(typing_extensions.TypedDict, total=False):
    executable: str
    executableVersion: typing_extensions.Literal[
        "RELEASE_EXECUTABLE_VERSION_UNSPECIFIED",
        "FIREBASE_RULES_EXECUTABLE_V1",
        "FIREBASE_RULES_EXECUTABLE_V2",
    ]
    language: typing_extensions.Literal[
        "LANGUAGE_UNSPECIFIED", "FIREBASE_RULES", "EVENT_FLOW_TRIGGERS"
    ]
    rulesetName: str
    syncTime: str
    updateTime: str

@typing.type_check_only
class Issue(typing_extensions.TypedDict, total=False):
    description: str
    severity: typing_extensions.Literal[
        "SEVERITY_UNSPECIFIED", "DEPRECATION", "WARNING", "ERROR"
    ]
    sourcePosition: SourcePosition

@typing.type_check_only
class ListReleasesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    releases: _list[Release]

@typing.type_check_only
class ListRulesetsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    rulesets: _list[Ruleset]

@typing.type_check_only
class Metadata(typing_extensions.TypedDict, total=False):
    services: _list[str]

@typing.type_check_only
class Release(typing_extensions.TypedDict, total=False):
    createTime: str
    name: str
    rulesetName: str
    updateTime: str

@typing.type_check_only
class Result(typing_extensions.TypedDict, total=False):
    undefined: Empty
    value: typing.Any

@typing.type_check_only
class Ruleset(typing_extensions.TypedDict, total=False):
    createTime: str
    metadata: Metadata
    name: str
    source: Source

@typing.type_check_only
class Source(typing_extensions.TypedDict, total=False):
    files: _list[File]

@typing.type_check_only
class SourcePosition(typing_extensions.TypedDict, total=False):
    column: int
    currentOffset: int
    endOffset: int
    fileName: str
    line: int

@typing.type_check_only
class TestCase(typing_extensions.TypedDict, total=False):
    expectation: typing_extensions.Literal["EXPECTATION_UNSPECIFIED", "ALLOW", "DENY"]
    expressionReportLevel: typing_extensions.Literal[
        "LEVEL_UNSPECIFIED", "NONE", "FULL", "VISITED"
    ]
    functionMocks: _list[FunctionMock]
    pathEncoding: typing_extensions.Literal[
        "ENCODING_UNSPECIFIED", "URL_ENCODED", "PLAIN"
    ]
    request: typing.Any
    resource: typing.Any

@typing.type_check_only
class TestResult(typing_extensions.TypedDict, total=False):
    debugMessages: _list[str]
    errorPosition: SourcePosition
    expressionReports: _list[ExpressionReport]
    functionCalls: _list[FunctionCall]
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "SUCCESS", "FAILURE"]
    visitedExpressions: _list[VisitedExpression]

@typing.type_check_only
class TestRulesetRequest(typing_extensions.TypedDict, total=False):
    source: Source
    testSuite: TestSuite

@typing.type_check_only
class TestRulesetResponse(typing_extensions.TypedDict, total=False):
    issues: _list[Issue]
    testResults: _list[TestResult]

@typing.type_check_only
class TestSuite(typing_extensions.TypedDict, total=False):
    testCases: _list[TestCase]

@typing.type_check_only
class UpdateReleaseRequest(typing_extensions.TypedDict, total=False):
    release: Release
    updateMask: str

@typing.type_check_only
class ValueCount(typing_extensions.TypedDict, total=False):
    count: int
    value: typing.Any

@typing.type_check_only
class VisitedExpression(typing_extensions.TypedDict, total=False):
    sourcePosition: SourcePosition
    value: typing.Any



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class WebSecurityScannerResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ScanConfigsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class ScanRunsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class CrawledUrlsResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListCrawledUrlsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListCrawledUrlsResponseHttpRequest,
                        previous_response: ListCrawledUrlsResponse,
                    ) -> ListCrawledUrlsResponseHttpRequest | None: ...

                @typing.type_check_only
                class FindingTypeStatsResource(googleapiclient.discovery.Resource):
                    def list(
                        self, *, parent: str, **kwargs: typing.Any
                    ) -> ListFindingTypeStatsResponseHttpRequest: ...

                @typing.type_check_only
                class FindingsResource(googleapiclient.discovery.Resource):
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> FindingHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListFindingsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListFindingsResponseHttpRequest,
                        previous_response: ListFindingsResponse,
                    ) -> ListFindingsResponseHttpRequest | None: ...

                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> ScanRunHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListScanRunsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListScanRunsResponseHttpRequest,
                    previous_response: ListScanRunsResponse,
                ) -> ListScanRunsResponseHttpRequest | None: ...
                def stop(
                    self,
                    *,
                    name: str,
                    body: StopScanRunRequest = ...,
                    **kwargs: typing.Any
                ) -> ScanRunHttpRequest: ...
                def crawledUrls(self) -> CrawledUrlsResource: ...
                def findingTypeStats(self) -> FindingTypeStatsResource: ...
                def findings(self) -> FindingsResource: ...

            def create(
                self, *, parent: str, body: ScanConfig = ..., **kwargs: typing.Any
            ) -> ScanConfigHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> ScanConfigHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListScanConfigsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListScanConfigsResponseHttpRequest,
                previous_response: ListScanConfigsResponse,
            ) -> ListScanConfigsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: ScanConfig = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> ScanConfigHttpRequest: ...
            def start(
                self,
                *,
                name: str,
                body: StartScanRunRequest = ...,
                **kwargs: typing.Any
            ) -> ScanRunHttpRequest: ...
            def scanRuns(self) -> ScanRunsResource: ...

        def scanConfigs(self) -> ScanConfigsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class FindingHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Finding: ...

@typing.type_check_only
class ListCrawledUrlsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCrawledUrlsResponse: ...

@typing.type_check_only
class ListFindingTypeStatsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListFindingTypeStatsResponse: ...

@typing.type_check_only
class ListFindingsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListFindingsResponse: ...

@typing.type_check_only
class ListScanConfigsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListScanConfigsResponse: ...

@typing.type_check_only
class ListScanRunsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListScanRunsResponse: ...

@typing.type_check_only
class ScanConfigHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ScanConfig: ...

@typing.type_check_only
class ScanRunHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ScanRun: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleSearchIdeahubV1alphaAvailableLocale(
    typing_extensions.TypedDict, total=False
):
    locale: str
    name: str

@typing.type_check_only
class GoogleSearchIdeahubV1alphaIdea(typing_extensions.TypedDict, total=False):
    name: str
    text: str
    topics: _list[GoogleSearchIdeahubV1alphaTopic]

@typing.type_check_only
class GoogleSearchIdeahubV1alphaIdeaActivity(typing_extensions.TypedDict, total=False):
    ideas: _list[str]
    name: str
    topics: _list[str]
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED",
        "POST_DRAFTED",
        "POST_PUBLISHED",
        "POST_DELETED",
        "POST_UNPUBLISHED",
    ]
    uri: str

@typing.type_check_only
class GoogleSearchIdeahubV1alphaIdeaState(typing_extensions.TypedDict, total=False):
    dismissed: bool
    name: str
    saved: bool

@typing.type_check_only
class GoogleSearchIdeahubV1alphaListAvailableLocalesResponse(
    typing_extensions.TypedDict, total=False
):
    availableLocales: _list[GoogleSearchIdeahubV1alphaAvailableLocale]
    nextPageToken: str

@typing.type_check_only
class GoogleSearchIdeahubV1alphaListIdeasResponse(
    typing_extensions.TypedDict, total=False
):
    ideas: _list[GoogleSearchIdeahubV1alphaIdea]
    nextPageToken: str

@typing.type_check_only
class GoogleSearchIdeahubV1alphaTopic(typing_extensions.TypedDict, total=False):
    displayName: str
    mid: str
    name: str

@typing.type_check_only
class GoogleSearchIdeahubV1alphaTopicState(typing_extensions.TypedDict, total=False):
    dismissed: bool
    name: str
    saved: bool



import typing

import typing_extensions

_list = list

@typing.type_check_only
class CheckValidCredsRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class CheckValidCredsResponse(typing_extensions.TypedDict, total=False):
    hasValidCreds: bool

@typing.type_check_only
class DataSource(typing_extensions.TypedDict, total=False):
    authorizationType: typing_extensions.Literal[
        "AUTHORIZATION_TYPE_UNSPECIFIED",
        "AUTHORIZATION_CODE",
        "GOOGLE_PLUS_AUTHORIZATION_CODE",
        "FIRST_PARTY_OAUTH",
    ]
    clientId: str
    dataRefreshType: typing_extensions.Literal[
        "DATA_REFRESH_TYPE_UNSPECIFIED", "SLIDING_WINDOW", "CUSTOM_SLIDING_WINDOW"
    ]
    dataSourceId: str
    defaultDataRefreshWindowDays: int
    defaultSchedule: str
    description: str
    displayName: str
    helpUrl: str
    manualRunsDisabled: bool
    minimumScheduleInterval: str
    name: str
    parameters: _list[DataSourceParameter]
    scopes: _list[str]
    supportsCustomSchedule: bool
    supportsMultipleTransfers: bool
    transferType: typing_extensions.Literal[
        "TRANSFER_TYPE_UNSPECIFIED", "BATCH", "STREAMING"
    ]
    updateDeadlineSeconds: int

@typing.type_check_only
class DataSourceParameter(typing_extensions.TypedDict, total=False):
    allowedValues: _list[str]
    deprecated: bool
    description: str
    displayName: str
    fields: _list[DataSourceParameter]
    immutable: bool
    maxValue: float
    minValue: float
    paramId: str
    recurse: bool
    repeated: bool
    required: bool
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED",
        "STRING",
        "INTEGER",
        "DOUBLE",
        "BOOLEAN",
        "RECORD",
        "PLUS_PAGE",
    ]
    validationDescription: str
    validationHelpUrl: str
    validationRegex: str

@typing.type_check_only
class EmailPreferences(typing_extensions.TypedDict, total=False):
    enableFailureEmail: bool

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class EnrollDataSourcesRequest(typing_extensions.TypedDict, total=False):
    dataSourceIds: _list[str]

@typing.type_check_only
class ListDataSourcesResponse(typing_extensions.TypedDict, total=False):
    dataSources: _list[DataSource]
    nextPageToken: str

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListTransferConfigsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    transferConfigs: _list[TransferConfig]

@typing.type_check_only
class ListTransferLogsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    transferMessages: _list[TransferMessage]

@typing.type_check_only
class ListTransferRunsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    transferRuns: _list[TransferRun]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class ScheduleOptions(typing_extensions.TypedDict, total=False):
    disableAutoScheduling: bool
    endTime: str
    startTime: str

@typing.type_check_only
class ScheduleTransferRunsRequest(typing_extensions.TypedDict, total=False):
    endTime: str
    startTime: str

@typing.type_check_only
class ScheduleTransferRunsResponse(typing_extensions.TypedDict, total=False):
    runs: _list[TransferRun]

@typing.type_check_only
class StartManualTransferRunsRequest(typing_extensions.TypedDict, total=False):
    requestedRunTime: str
    requestedTimeRange: TimeRange

@typing.type_check_only
class StartManualTransferRunsResponse(typing_extensions.TypedDict, total=False):
    runs: _list[TransferRun]

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class TimeRange(typing_extensions.TypedDict, total=False):
    endTime: str
    startTime: str

@typing.type_check_only
class TransferConfig(typing_extensions.TypedDict, total=False):
    dataRefreshWindowDays: int
    dataSourceId: str
    datasetRegion: str
    destinationDatasetId: str
    disabled: bool
    displayName: str
    emailPreferences: EmailPreferences
    name: str
    nextRunTime: str
    notificationPubsubTopic: str
    ownerInfo: UserInfo
    params: dict[str, typing.Any]
    schedule: str
    scheduleOptions: ScheduleOptions
    state: typing_extensions.Literal[
        "TRANSFER_STATE_UNSPECIFIED",
        "PENDING",
        "RUNNING",
        "SUCCEEDED",
        "FAILED",
        "CANCELLED",
    ]
    updateTime: str
    userId: str

@typing.type_check_only
class TransferMessage(typing_extensions.TypedDict, total=False):
    messageText: str
    messageTime: str
    severity: typing_extensions.Literal[
        "MESSAGE_SEVERITY_UNSPECIFIED", "INFO", "WARNING", "ERROR"
    ]

@typing.type_check_only
class TransferRun(typing_extensions.TypedDict, total=False):
    dataSourceId: str
    destinationDatasetId: str
    emailPreferences: EmailPreferences
    endTime: str
    errorStatus: Status
    name: str
    notificationPubsubTopic: str
    params: dict[str, typing.Any]
    runTime: str
    schedule: str
    scheduleTime: str
    startTime: str
    state: typing_extensions.Literal[
        "TRANSFER_STATE_UNSPECIFIED",
        "PENDING",
        "RUNNING",
        "SUCCEEDED",
        "FAILED",
        "CANCELLED",
    ]
    updateTime: str
    userId: str

@typing.type_check_only
class UserInfo(typing_extensions.TypedDict, total=False):
    email: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class AccessApprovalResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class FoldersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ApprovalRequestsResource(googleapiclient.discovery.Resource):
            def approve(
                self,
                *,
                name: str,
                body: ApproveApprovalRequestMessage = ...,
                **kwargs: typing.Any
            ) -> ApprovalRequestHttpRequest: ...
            def dismiss(
                self,
                *,
                name: str,
                body: DismissApprovalRequestMessage = ...,
                **kwargs: typing.Any
            ) -> ApprovalRequestHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> ApprovalRequestHttpRequest: ...
            def invalidate(
                self,
                *,
                name: str,
                body: InvalidateApprovalRequestMessage = ...,
                **kwargs: typing.Any
            ) -> ApprovalRequestHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListApprovalRequestsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListApprovalRequestsResponseHttpRequest,
                previous_response: ListApprovalRequestsResponse,
            ) -> ListApprovalRequestsResponseHttpRequest | None: ...

        def deleteAccessApprovalSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def getAccessApprovalSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> AccessApprovalSettingsHttpRequest: ...
        def getServiceAccount(
            self, *, name: str, **kwargs: typing.Any
        ) -> AccessApprovalServiceAccountHttpRequest: ...
        def updateAccessApprovalSettings(
            self,
            *,
            name: str,
            body: AccessApprovalSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> AccessApprovalSettingsHttpRequest: ...
        def approvalRequests(self) -> ApprovalRequestsResource: ...

    @typing.type_check_only
    class OrganizationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ApprovalRequestsResource(googleapiclient.discovery.Resource):
            def approve(
                self,
                *,
                name: str,
                body: ApproveApprovalRequestMessage = ...,
                **kwargs: typing.Any
            ) -> ApprovalRequestHttpRequest: ...
            def dismiss(
                self,
                *,
                name: str,
                body: DismissApprovalRequestMessage = ...,
                **kwargs: typing.Any
            ) -> ApprovalRequestHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> ApprovalRequestHttpRequest: ...
            def invalidate(
                self,
                *,
                name: str,
                body: InvalidateApprovalRequestMessage = ...,
                **kwargs: typing.Any
            ) -> ApprovalRequestHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListApprovalRequestsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListApprovalRequestsResponseHttpRequest,
                previous_response: ListApprovalRequestsResponse,
            ) -> ListApprovalRequestsResponseHttpRequest | None: ...

        def deleteAccessApprovalSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def getAccessApprovalSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> AccessApprovalSettingsHttpRequest: ...
        def getServiceAccount(
            self, *, name: str, **kwargs: typing.Any
        ) -> AccessApprovalServiceAccountHttpRequest: ...
        def updateAccessApprovalSettings(
            self,
            *,
            name: str,
            body: AccessApprovalSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> AccessApprovalSettingsHttpRequest: ...
        def approvalRequests(self) -> ApprovalRequestsResource: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ApprovalRequestsResource(googleapiclient.discovery.Resource):
            def approve(
                self,
                *,
                name: str,
                body: ApproveApprovalRequestMessage = ...,
                **kwargs: typing.Any
            ) -> ApprovalRequestHttpRequest: ...
            def dismiss(
                self,
                *,
                name: str,
                body: DismissApprovalRequestMessage = ...,
                **kwargs: typing.Any
            ) -> ApprovalRequestHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> ApprovalRequestHttpRequest: ...
            def invalidate(
                self,
                *,
                name: str,
                body: InvalidateApprovalRequestMessage = ...,
                **kwargs: typing.Any
            ) -> ApprovalRequestHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListApprovalRequestsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListApprovalRequestsResponseHttpRequest,
                previous_response: ListApprovalRequestsResponse,
            ) -> ListApprovalRequestsResponseHttpRequest | None: ...

        def deleteAccessApprovalSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def getAccessApprovalSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> AccessApprovalSettingsHttpRequest: ...
        def getServiceAccount(
            self, *, name: str, **kwargs: typing.Any
        ) -> AccessApprovalServiceAccountHttpRequest: ...
        def updateAccessApprovalSettings(
            self,
            *,
            name: str,
            body: AccessApprovalSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> AccessApprovalSettingsHttpRequest: ...
        def approvalRequests(self) -> ApprovalRequestsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def folders(self) -> FoldersResource: ...
    def organizations(self) -> OrganizationsResource: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class AccessApprovalServiceAccountHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccessApprovalServiceAccount: ...

@typing.type_check_only
class AccessApprovalSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccessApprovalSettings: ...

@typing.type_check_only
class ApprovalRequestHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ApprovalRequest: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListApprovalRequestsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListApprovalRequestsResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class ResellerResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class CustomersResource(googleapiclient.discovery.Resource):
        def get(
            self, *, customerId: str, **kwargs: typing.Any
        ) -> CustomerHttpRequest: ...
        def insert(
            self,
            *,
            body: Customer = ...,
            customerAuthToken: str = ...,
            **kwargs: typing.Any
        ) -> CustomerHttpRequest: ...
        def patch(
            self, *, customerId: str, body: Customer = ..., **kwargs: typing.Any
        ) -> CustomerHttpRequest: ...
        def update(
            self, *, customerId: str, body: Customer = ..., **kwargs: typing.Any
        ) -> CustomerHttpRequest: ...

    @typing.type_check_only
    class ResellernotifyResource(googleapiclient.discovery.Resource):
        def getwatchdetails(
            self, **kwargs: typing.Any
        ) -> ResellernotifyGetwatchdetailsResponseHttpRequest: ...
        def register(
            self, *, serviceAccountEmailAddress: str = ..., **kwargs: typing.Any
        ) -> ResellernotifyResourceHttpRequest: ...
        def unregister(
            self, *, serviceAccountEmailAddress: str = ..., **kwargs: typing.Any
        ) -> ResellernotifyResourceHttpRequest: ...

    @typing.type_check_only
    class SubscriptionsResource(googleapiclient.discovery.Resource):
        def activate(
            self, *, customerId: str, subscriptionId: str, **kwargs: typing.Any
        ) -> SubscriptionHttpRequest: ...
        def changePlan(
            self,
            *,
            customerId: str,
            subscriptionId: str,
            body: ChangePlanRequest = ...,
            **kwargs: typing.Any
        ) -> SubscriptionHttpRequest: ...
        def changeRenewalSettings(
            self,
            *,
            customerId: str,
            subscriptionId: str,
            body: RenewalSettings = ...,
            **kwargs: typing.Any
        ) -> SubscriptionHttpRequest: ...
        def changeSeats(
            self,
            *,
            customerId: str,
            subscriptionId: str,
            body: Seats = ...,
            **kwargs: typing.Any
        ) -> SubscriptionHttpRequest: ...
        def delete(
            self,
            *,
            customerId: str,
            subscriptionId: str,
            deletionType: typing_extensions.Literal[
                "deletion_type_undefined", "cancel", "transfer_to_direct"
            ],
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, customerId: str, subscriptionId: str, **kwargs: typing.Any
        ) -> SubscriptionHttpRequest: ...
        def insert(
            self,
            *,
            customerId: str,
            body: Subscription = ...,
            customerAuthToken: str = ...,
            **kwargs: typing.Any
        ) -> SubscriptionHttpRequest: ...
        def list(
            self,
            *,
            customerAuthToken: str = ...,
            customerId: str = ...,
            customerNamePrefix: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> SubscriptionsHttpRequest: ...
        def list_next(
            self,
            previous_request: SubscriptionsHttpRequest,
            previous_response: Subscriptions,
        ) -> SubscriptionsHttpRequest | None: ...
        def startPaidService(
            self, *, customerId: str, subscriptionId: str, **kwargs: typing.Any
        ) -> SubscriptionHttpRequest: ...
        def suspend(
            self, *, customerId: str, subscriptionId: str, **kwargs: typing.Any
        ) -> SubscriptionHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def customers(self) -> CustomersResource: ...
    def resellernotify(self) -> ResellernotifyResource: ...
    def subscriptions(self) -> SubscriptionsResource: ...

@typing.type_check_only
class CustomerHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Customer: ...

@typing.type_check_only
class ResellernotifyGetwatchdetailsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ResellernotifyGetwatchdetailsResponse: ...

@typing.type_check_only
class ResellernotifyResourceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ResellernotifyResource: ...

@typing.type_check_only
class SubscriptionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Subscription: ...

@typing.type_check_only
class SubscriptionsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Subscriptions: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudBuildResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class GithubDotComWebhookResource(googleapiclient.discovery.Resource):
        def receive(
            self, *, body: HttpBody = ..., webhookKey: str = ..., **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...

    @typing.type_check_only
    class LocationsResource(googleapiclient.discovery.Resource):
        def regionalWebhook(
            self,
            *,
            location: str,
            body: HttpBody = ...,
            webhookKey: str = ...,
            **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...

    @typing.type_check_only
    class OperationsResource(googleapiclient.discovery.Resource):
        def cancel(
            self, *, name: str, body: CancelOperationRequest = ..., **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def get(self, *, name: str, **kwargs: typing.Any) -> OperationHttpRequest: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class BuildsResource(googleapiclient.discovery.Resource):
            def approve(
                self,
                *,
                name: str,
                body: ApproveBuildRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def cancel(
                self,
                *,
                projectId: str,
                id: str,
                body: CancelBuildRequest = ...,
                **kwargs: typing.Any
            ) -> BuildHttpRequest: ...
            def create(
                self,
                *,
                projectId: str,
                body: Build = ...,
                parent: str = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def get(
                self, *, projectId: str, id: str, name: str = ..., **kwargs: typing.Any
            ) -> BuildHttpRequest: ...
            def list(
                self,
                *,
                projectId: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                parent: str = ...,
                **kwargs: typing.Any
            ) -> ListBuildsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListBuildsResponseHttpRequest,
                previous_response: ListBuildsResponse,
            ) -> ListBuildsResponseHttpRequest | None: ...
            def retry(
                self,
                *,
                projectId: str,
                id: str,
                body: RetryBuildRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        @typing.type_check_only
        class GithubEnterpriseConfigsResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: GitHubEnterpriseConfig = ...,
                gheConfigId: str = ...,
                projectId: str = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def delete(
                self,
                *,
                name: str,
                configId: str = ...,
                projectId: str = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def get(
                self,
                *,
                name: str,
                configId: str = ...,
                projectId: str = ...,
                **kwargs: typing.Any
            ) -> GitHubEnterpriseConfigHttpRequest: ...
            def list(
                self, *, parent: str, projectId: str = ..., **kwargs: typing.Any
            ) -> ListGithubEnterpriseConfigsResponseHttpRequest: ...
            def patch(
                self,
                *,
                name: str,
                body: GitHubEnterpriseConfig = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class BitbucketServerConfigsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class ConnectedRepositoriesResource(googleapiclient.discovery.Resource):
                    def batchCreate(
                        self,
                        *,
                        parent: str,
                        body: BatchCreateBitbucketServerConnectedRepositoriesRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...

                @typing.type_check_only
                class ReposResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListBitbucketServerRepositoriesResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListBitbucketServerRepositoriesResponseHttpRequest,
                        previous_response: ListBitbucketServerRepositoriesResponse,
                    ) -> ListBitbucketServerRepositoriesResponseHttpRequest | None: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: BitbucketServerConfig = ...,
                    bitbucketServerConfigId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> BitbucketServerConfigHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListBitbucketServerConfigsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListBitbucketServerConfigsResponseHttpRequest,
                    previous_response: ListBitbucketServerConfigsResponse,
                ) -> ListBitbucketServerConfigsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: BitbucketServerConfig = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def removeBitbucketServerConnectedRepository(
                    self,
                    *,
                    config: str,
                    body: RemoveBitbucketServerConnectedRepositoryRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def connectedRepositories(self) -> ConnectedRepositoriesResource: ...
                def repos(self) -> ReposResource: ...

            @typing.type_check_only
            class BuildsResource(googleapiclient.discovery.Resource):
                def approve(
                    self,
                    *,
                    name: str,
                    body: ApproveBuildRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def cancel(
                    self,
                    *,
                    name: str,
                    body: CancelBuildRequest = ...,
                    **kwargs: typing.Any
                ) -> BuildHttpRequest: ...
                def create(
                    self,
                    *,
                    parent: str,
                    body: Build = ...,
                    projectId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self,
                    *,
                    name: str,
                    id: str = ...,
                    projectId: str = ...,
                    **kwargs: typing.Any
                ) -> BuildHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    projectId: str = ...,
                    **kwargs: typing.Any
                ) -> ListBuildsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListBuildsResponseHttpRequest,
                    previous_response: ListBuildsResponse,
                ) -> ListBuildsResponseHttpRequest | None: ...
                def retry(
                    self,
                    *,
                    name: str,
                    body: RetryBuildRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            @typing.type_check_only
            class GitLabConfigsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class ConnectedRepositoriesResource(googleapiclient.discovery.Resource):
                    def batchCreate(
                        self,
                        *,
                        parent: str,
                        body: BatchCreateGitLabConnectedRepositoriesRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...

                @typing.type_check_only
                class ReposResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListGitLabRepositoriesResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListGitLabRepositoriesResponseHttpRequest,
                        previous_response: ListGitLabRepositoriesResponse,
                    ) -> ListGitLabRepositoriesResponseHttpRequest | None: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: GitLabConfig = ...,
                    gitlabConfigId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GitLabConfigHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListGitLabConfigsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListGitLabConfigsResponseHttpRequest,
                    previous_response: ListGitLabConfigsResponse,
                ) -> ListGitLabConfigsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GitLabConfig = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def removeGitLabConnectedRepository(
                    self,
                    *,
                    config: str,
                    body: RemoveGitLabConnectedRepositoryRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def connectedRepositories(self) -> ConnectedRepositoriesResource: ...
                def repos(self) -> ReposResource: ...

            @typing.type_check_only
            class GithubEnterpriseConfigsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GitHubEnterpriseConfig = ...,
                    gheConfigId: str = ...,
                    projectId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self,
                    *,
                    name: str,
                    configId: str = ...,
                    projectId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self,
                    *,
                    name: str,
                    configId: str = ...,
                    projectId: str = ...,
                    **kwargs: typing.Any
                ) -> GitHubEnterpriseConfigHttpRequest: ...
                def list(
                    self, *, parent: str, projectId: str = ..., **kwargs: typing.Any
                ) -> ListGithubEnterpriseConfigsResponseHttpRequest: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GitHubEnterpriseConfig = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self,
                    *,
                    name: str,
                    body: CancelOperationRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            @typing.type_check_only
            class TriggersResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: BuildTrigger = ...,
                    projectId: str = ...,
                    **kwargs: typing.Any
                ) -> BuildTriggerHttpRequest: ...
                def delete(
                    self,
                    *,
                    name: str,
                    projectId: str = ...,
                    triggerId: str = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self,
                    *,
                    name: str,
                    projectId: str = ...,
                    triggerId: str = ...,
                    **kwargs: typing.Any
                ) -> BuildTriggerHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    projectId: str = ...,
                    **kwargs: typing.Any
                ) -> ListBuildTriggersResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListBuildTriggersResponseHttpRequest,
                    previous_response: ListBuildTriggersResponse,
                ) -> ListBuildTriggersResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    resourceName: str,
                    body: BuildTrigger = ...,
                    projectId: str = ...,
                    triggerId: str = ...,
                    **kwargs: typing.Any
                ) -> BuildTriggerHttpRequest: ...
                def run(
                    self,
                    *,
                    name: str,
                    body: RunBuildTriggerRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def webhook(
                    self,
                    *,
                    name: str,
                    body: HttpBody = ...,
                    projectId: str = ...,
                    secret: str = ...,
                    trigger: str = ...,
                    **kwargs: typing.Any
                ) -> ReceiveTriggerWebhookResponseHttpRequest: ...

            @typing.type_check_only
            class WorkerPoolsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: WorkerPool = ...,
                    validateOnly: bool = ...,
                    workerPoolId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self,
                    *,
                    name: str,
                    allowMissing: bool = ...,
                    etag: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> WorkerPoolHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListWorkerPoolsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListWorkerPoolsResponseHttpRequest,
                    previous_response: ListWorkerPoolsResponse,
                ) -> ListWorkerPoolsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: WorkerPool = ...,
                    updateMask: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            def bitbucketServerConfigs(self) -> BitbucketServerConfigsResource: ...
            def builds(self) -> BuildsResource: ...
            def gitLabConfigs(self) -> GitLabConfigsResource: ...
            def githubEnterpriseConfigs(self) -> GithubEnterpriseConfigsResource: ...
            def operations(self) -> OperationsResource: ...
            def triggers(self) -> TriggersResource: ...
            def workerPools(self) -> WorkerPoolsResource: ...

        @typing.type_check_only
        class TriggersResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                projectId: str,
                body: BuildTrigger = ...,
                parent: str = ...,
                **kwargs: typing.Any
            ) -> BuildTriggerHttpRequest: ...
            def delete(
                self,
                *,
                projectId: str,
                triggerId: str,
                name: str = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self,
                *,
                projectId: str,
                triggerId: str,
                name: str = ...,
                **kwargs: typing.Any
            ) -> BuildTriggerHttpRequest: ...
            def list(
                self,
                *,
                projectId: str,
                pageSize: int = ...,
                pageToken: str = ...,
                parent: str = ...,
                **kwargs: typing.Any
            ) -> ListBuildTriggersResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListBuildTriggersResponseHttpRequest,
                previous_response: ListBuildTriggersResponse,
            ) -> ListBuildTriggersResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                projectId: str,
                triggerId: str,
                body: BuildTrigger = ...,
                **kwargs: typing.Any
            ) -> BuildTriggerHttpRequest: ...
            def run(
                self,
                *,
                projectId: str,
                triggerId: str,
                body: RepoSource = ...,
                name: str = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def webhook(
                self,
                *,
                projectId: str,
                trigger: str,
                body: HttpBody = ...,
                name: str = ...,
                secret: str = ...,
                **kwargs: typing.Any
            ) -> ReceiveTriggerWebhookResponseHttpRequest: ...

        def builds(self) -> BuildsResource: ...
        def githubEnterpriseConfigs(self) -> GithubEnterpriseConfigsResource: ...
        def locations(self) -> LocationsResource: ...
        def triggers(self) -> TriggersResource: ...

    @typing.type_check_only
    class V1Resource(googleapiclient.discovery.Resource):
        def webhook(
            self, *, body: HttpBody = ..., webhookKey: str = ..., **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def githubDotComWebhook(self) -> GithubDotComWebhookResource: ...
    def locations(self) -> LocationsResource: ...
    def operations(self) -> OperationsResource: ...
    def projects(self) -> ProjectsResource: ...
    def v1(self) -> V1Resource: ...

@typing.type_check_only
class BitbucketServerConfigHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BitbucketServerConfig: ...

@typing.type_check_only
class BuildHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Build: ...

@typing.type_check_only
class BuildTriggerHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BuildTrigger: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class GitHubEnterpriseConfigHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GitHubEnterpriseConfig: ...

@typing.type_check_only
class GitLabConfigHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GitLabConfig: ...

@typing.type_check_only
class ListBitbucketServerConfigsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListBitbucketServerConfigsResponse: ...

@typing.type_check_only
class ListBitbucketServerRepositoriesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListBitbucketServerRepositoriesResponse: ...

@typing.type_check_only
class ListBuildTriggersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListBuildTriggersResponse: ...

@typing.type_check_only
class ListBuildsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListBuildsResponse: ...

@typing.type_check_only
class ListGitLabConfigsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListGitLabConfigsResponse: ...

@typing.type_check_only
class ListGitLabRepositoriesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListGitLabRepositoriesResponse: ...

@typing.type_check_only
class ListGithubEnterpriseConfigsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListGithubEnterpriseConfigsResponse: ...

@typing.type_check_only
class ListWorkerPoolsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListWorkerPoolsResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class ReceiveTriggerWebhookResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReceiveTriggerWebhookResponse: ...

@typing.type_check_only
class WorkerPoolHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> WorkerPool: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Account(typing_extensions.TypedDict, total=False):
    accountId: str
    fingerprint: str
    name: str
    shareData: bool

@typing.type_check_only
class AccountAccess(typing_extensions.TypedDict, total=False):
    permission: _list[str]

@typing.type_check_only
class Condition(typing_extensions.TypedDict, total=False):
    parameter: _list[Parameter]
    type: typing_extensions.Literal[
        "equals",
        "contains",
        "startsWith",
        "endsWith",
        "matchRegex",
        "greater",
        "greaterOrEquals",
        "less",
        "lessOrEquals",
        "cssSelector",
        "urlMatches",
    ]

@typing.type_check_only
class Container(typing_extensions.TypedDict, total=False):
    accountId: str
    containerId: str
    domainName: _list[str]
    enabledBuiltInVariable: _list[str]
    fingerprint: str
    name: str
    notes: str
    publicId: str
    timeZoneCountryId: str
    timeZoneId: str
    usageContext: _list[str]

@typing.type_check_only
class ContainerAccess(typing_extensions.TypedDict, total=False):
    containerId: str
    permission: _list[str]

@typing.type_check_only
class ContainerVersion(typing_extensions.TypedDict, total=False):
    accountId: str
    container: Container
    containerId: str
    containerVersionId: str
    deleted: bool
    fingerprint: str
    folder: _list[Folder]
    macro: _list[Macro]
    name: str
    notes: str
    rule: _list[Rule]
    tag: _list[Tag]
    trigger: _list[Trigger]
    variable: _list[Variable]

@typing.type_check_only
class ContainerVersionHeader(typing_extensions.TypedDict, total=False):
    accountId: str
    containerId: str
    containerVersionId: str
    deleted: bool
    name: str
    numMacros: str
    numRules: str
    numTags: str
    numTriggers: str
    numVariables: str

@typing.type_check_only
class CreateContainerVersionRequestVersionOptions(
    typing_extensions.TypedDict, total=False
):
    name: str
    notes: str
    quickPreview: bool

@typing.type_check_only
class CreateContainerVersionResponse(typing_extensions.TypedDict, total=False):
    compilerError: bool
    containerVersion: ContainerVersion

@typing.type_check_only
class Environment(typing_extensions.TypedDict, total=False):
    accountId: str
    authorizationCode: str
    authorizationTimestampMs: str
    containerId: str
    containerVersionId: str
    description: str
    enableDebug: bool
    environmentId: str
    fingerprint: str
    name: str
    type: typing_extensions.Literal["user", "live", "latest", "draft"]
    url: str

@typing.type_check_only
class Folder(typing_extensions.TypedDict, total=False):
    accountId: str
    containerId: str
    fingerprint: str
    folderId: str
    name: str

@typing.type_check_only
class FolderEntities(typing_extensions.TypedDict, total=False):
    tag: _list[Tag]
    trigger: _list[Trigger]
    variable: _list[Variable]

@typing.type_check_only
class ListAccountUsersResponse(typing_extensions.TypedDict, total=False):
    userAccess: _list[UserAccess]

@typing.type_check_only
class ListAccountsResponse(typing_extensions.TypedDict, total=False):
    accounts: _list[Account]

@typing.type_check_only
class ListContainerVersionsResponse(typing_extensions.TypedDict, total=False):
    containerVersion: _list[ContainerVersion]
    containerVersionHeader: _list[ContainerVersionHeader]

@typing.type_check_only
class ListContainersResponse(typing_extensions.TypedDict, total=False):
    containers: _list[Container]

@typing.type_check_only
class ListEnvironmentsResponse(typing_extensions.TypedDict, total=False):
    environments: _list[Environment]

@typing.type_check_only
class ListFoldersResponse(typing_extensions.TypedDict, total=False):
    folders: _list[Folder]

@typing.type_check_only
class ListTagsResponse(typing_extensions.TypedDict, total=False):
    tags: _list[Tag]

@typing.type_check_only
class ListTriggersResponse(typing_extensions.TypedDict, total=False):
    triggers: _list[Trigger]

@typing.type_check_only
class ListVariablesResponse(typing_extensions.TypedDict, total=False):
    variables: _list[Variable]

@typing.type_check_only
class Macro(typing_extensions.TypedDict, total=False):
    accountId: str
    containerId: str
    disablingRuleId: _list[str]
    enablingRuleId: _list[str]
    fingerprint: str
    macroId: str
    name: str
    notes: str
    parameter: _list[Parameter]
    parentFolderId: str
    scheduleEndMs: str
    scheduleStartMs: str
    type: str

@typing.type_check_only
class Parameter(typing_extensions.TypedDict, total=False):
    key: str
    list: _list[Parameter]
    map: _list[Parameter]
    type: typing_extensions.Literal[
        "template",
        "integer",
        "boolean",
        "list",
        "map",
        "triggerReference",
        "tagReference",
    ]
    value: str

@typing.type_check_only
class PublishContainerVersionResponse(typing_extensions.TypedDict, total=False):
    compilerError: bool
    containerVersion: ContainerVersion

@typing.type_check_only
class Rule(typing_extensions.TypedDict, total=False):
    accountId: str
    condition: _list[Condition]
    containerId: str
    fingerprint: str
    name: str
    notes: str
    ruleId: str

@typing.type_check_only
class SetupTag(typing_extensions.TypedDict, total=False):
    stopOnSetupFailure: bool
    tagName: str

@typing.type_check_only
class Tag(typing_extensions.TypedDict, total=False):
    accountId: str
    blockingRuleId: _list[str]
    blockingTriggerId: _list[str]
    containerId: str
    fingerprint: str
    firingRuleId: _list[str]
    firingTriggerId: _list[str]
    liveOnly: bool
    name: str
    notes: str
    parameter: _list[Parameter]
    parentFolderId: str
    paused: bool
    priority: Parameter
    scheduleEndMs: str
    scheduleStartMs: str
    setupTag: _list[SetupTag]
    tagFiringOption: typing_extensions.Literal[
        "unlimited", "oncePerEvent", "oncePerLoad"
    ]
    tagId: str
    teardownTag: _list[TeardownTag]
    type: str

@typing.type_check_only
class TeardownTag(typing_extensions.TypedDict, total=False):
    stopTeardownOnFailure: bool
    tagName: str

@typing.type_check_only
class Trigger(typing_extensions.TypedDict, total=False):
    accountId: str
    autoEventFilter: _list[Condition]
    checkValidation: Parameter
    containerId: str
    continuousTimeMinMilliseconds: Parameter
    customEventFilter: _list[Condition]
    eventName: Parameter
    filter: _list[Condition]
    fingerprint: str
    horizontalScrollPercentageList: Parameter
    interval: Parameter
    intervalSeconds: Parameter
    limit: Parameter
    maxTimerLengthSeconds: Parameter
    name: str
    parameter: _list[Parameter]
    parentFolderId: str
    selector: Parameter
    totalTimeMinMilliseconds: Parameter
    triggerId: str
    type: typing_extensions.Literal[
        "pageview",
        "domReady",
        "windowLoaded",
        "customEvent",
        "triggerGroup",
        "always",
        "formSubmission",
        "click",
        "linkClick",
        "jsError",
        "historyChange",
        "timer",
        "ampClick",
        "ampTimer",
        "ampScroll",
        "ampVisibility",
        "youTubeVideo",
        "scrollDepth",
        "elementVisibility",
    ]
    uniqueTriggerId: Parameter
    verticalScrollPercentageList: Parameter
    visibilitySelector: Parameter
    visiblePercentageMax: Parameter
    visiblePercentageMin: Parameter
    waitForTags: Parameter
    waitForTagsTimeout: Parameter

@typing.type_check_only
class UserAccess(typing_extensions.TypedDict, total=False):
    accountAccess: AccountAccess
    accountId: str
    containerAccess: _list[ContainerAccess]
    emailAddress: str
    permissionId: str

@typing.type_check_only
class Variable(typing_extensions.TypedDict, total=False):
    accountId: str
    containerId: str
    disablingTriggerId: _list[str]
    enablingTriggerId: _list[str]
    fingerprint: str
    name: str
    notes: str
    parameter: _list[Parameter]
    parentFolderId: str
    scheduleEndMs: str
    scheduleStartMs: str
    type: str
    variableId: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class AndroidManagementResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class EnterprisesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ApplicationsResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, languageCode: str = ..., **kwargs: typing.Any
            ) -> ApplicationHttpRequest: ...

        @typing.type_check_only
        class DevicesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def list(
                    self,
                    *,
                    name: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListOperationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListOperationsResponseHttpRequest,
                    previous_response: ListOperationsResponse,
                ) -> ListOperationsResponseHttpRequest | None: ...

            def delete(
                self,
                *,
                name: str,
                wipeDataFlags: typing_extensions.Literal[
                    "WIPE_DATA_FLAG_UNSPECIFIED",
                    "PRESERVE_RESET_PROTECTION_DATA",
                    "WIPE_EXTERNAL_STORAGE",
                ]
                | _list[
                    typing_extensions.Literal[
                        "WIPE_DATA_FLAG_UNSPECIFIED",
                        "PRESERVE_RESET_PROTECTION_DATA",
                        "WIPE_EXTERNAL_STORAGE",
                    ]
                ] = ...,
                wipeReasonMessage: str = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> DeviceHttpRequest: ...
            def issueCommand(
                self, *, name: str, body: Command = ..., **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListDevicesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListDevicesResponseHttpRequest,
                previous_response: ListDevicesResponse,
            ) -> ListDevicesResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: Device = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> DeviceHttpRequest: ...
            def operations(self) -> OperationsResource: ...

        @typing.type_check_only
        class EnrollmentTokensResource(googleapiclient.discovery.Resource):
            def create(
                self, *, parent: str, body: EnrollmentToken = ..., **kwargs: typing.Any
            ) -> EnrollmentTokenHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> EnrollmentTokenHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListEnrollmentTokensResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListEnrollmentTokensResponseHttpRequest,
                previous_response: ListEnrollmentTokensResponse,
            ) -> ListEnrollmentTokensResponseHttpRequest | None: ...

        @typing.type_check_only
        class PoliciesResource(googleapiclient.discovery.Resource):
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> PolicyHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListPoliciesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListPoliciesResponseHttpRequest,
                previous_response: ListPoliciesResponse,
            ) -> ListPoliciesResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: Policy = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...

        @typing.type_check_only
        class WebAppsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, parent: str, body: WebApp = ..., **kwargs: typing.Any
            ) -> WebAppHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> WebAppHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListWebAppsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListWebAppsResponseHttpRequest,
                previous_response: ListWebAppsResponse,
            ) -> ListWebAppsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: WebApp = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> WebAppHttpRequest: ...

        @typing.type_check_only
        class WebTokensResource(googleapiclient.discovery.Resource):
            def create(
                self, *, parent: str, body: WebToken = ..., **kwargs: typing.Any
            ) -> WebTokenHttpRequest: ...

        def create(
            self,
            *,
            body: Enterprise = ...,
            agreementAccepted: bool = ...,
            enterpriseToken: str = ...,
            projectId: str = ...,
            signupUrlName: str = ...,
            **kwargs: typing.Any
        ) -> EnterpriseHttpRequest: ...
        def delete(self, *, name: str, **kwargs: typing.Any) -> EmptyHttpRequest: ...
        def get(self, *, name: str, **kwargs: typing.Any) -> EnterpriseHttpRequest: ...
        def list(
            self,
            *,
            pageSize: int = ...,
            pageToken: str = ...,
            projectId: str = ...,
            view: typing_extensions.Literal[
                "ENTERPRISE_VIEW_UNSPECIFIED", "BASIC"
            ] = ...,
            **kwargs: typing.Any
        ) -> ListEnterprisesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListEnterprisesResponseHttpRequest,
            previous_response: ListEnterprisesResponse,
        ) -> ListEnterprisesResponseHttpRequest | None: ...
        def patch(
            self,
            *,
            name: str,
            body: Enterprise = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> EnterpriseHttpRequest: ...
        def applications(self) -> ApplicationsResource: ...
        def devices(self) -> DevicesResource: ...
        def enrollmentTokens(self) -> EnrollmentTokensResource: ...
        def policies(self) -> PoliciesResource: ...
        def webApps(self) -> WebAppsResource: ...
        def webTokens(self) -> WebTokensResource: ...

    @typing.type_check_only
    class SignupUrlsResource(googleapiclient.discovery.Resource):
        def create(
            self, *, callbackUrl: str = ..., projectId: str = ..., **kwargs: typing.Any
        ) -> SignupUrlHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def enterprises(self) -> EnterprisesResource: ...
    def signupUrls(self) -> SignupUrlsResource: ...

@typing.type_check_only
class ApplicationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Application: ...

@typing.type_check_only
class DeviceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Device: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class EnrollmentTokenHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> EnrollmentToken: ...

@typing.type_check_only
class EnterpriseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Enterprise: ...

@typing.type_check_only
class ListDevicesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDevicesResponse: ...

@typing.type_check_only
class ListEnrollmentTokensResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListEnrollmentTokensResponse: ...

@typing.type_check_only
class ListEnterprisesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListEnterprisesResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class ListPoliciesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPoliciesResponse: ...

@typing.type_check_only
class ListWebAppsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListWebAppsResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class SignupUrlHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SignupUrl: ...

@typing.type_check_only
class WebAppHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> WebApp: ...

@typing.type_check_only
class WebTokenHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> WebToken: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class DriveActivityResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ActivityResource(googleapiclient.discovery.Resource):
        def query(
            self, *, body: QueryDriveActivityRequest = ..., **kwargs: typing.Any
        ) -> QueryDriveActivityResponseHttpRequest: ...
        def query_next(
            self,
            previous_request: QueryDriveActivityResponseHttpRequest,
            previous_response: QueryDriveActivityResponse,
        ) -> QueryDriveActivityResponseHttpRequest | None: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def activity(self) -> ActivityResource: ...

@typing.type_check_only
class QueryDriveActivityResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> QueryDriveActivityResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Channel(typing_extensions.TypedDict, total=False):
    channelType: typing_extensions.Literal[
        "CHANNEL_TYPE_UNSPECIFIED",
        "STABLE",
        "BETA",
        "DEV",
        "CANARY",
        "CANARY_ASAN",
        "ALL",
        "EXTENDED",
    ]
    name: str

@typing.type_check_only
class Interval(typing_extensions.TypedDict, total=False):
    endTime: str
    startTime: str

@typing.type_check_only
class ListChannelsResponse(typing_extensions.TypedDict, total=False):
    channels: _list[Channel]
    nextPageToken: str

@typing.type_check_only
class ListPlatformsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    platforms: _list[Platform]

@typing.type_check_only
class ListReleasesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    releases: _list[Release]

@typing.type_check_only
class ListVersionsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    versions: _list[Version]

@typing.type_check_only
class Platform(typing_extensions.TypedDict, total=False):
    name: str
    platformType: typing_extensions.Literal[
        "PLATFORM_TYPE_UNSPECIFIED",
        "WIN",
        "WIN64",
        "MAC",
        "LINUX",
        "ANDROID",
        "WEBVIEW",
        "IOS",
        "ALL",
        "MAC_ARM64",
        "LACROS",
        "LACROS_ARM32",
        "CHROMEOS",
        "LACROS_ARM64",
    ]

@typing.type_check_only
class Release(typing_extensions.TypedDict, total=False):
    fraction: float
    fractionGroup: str
    name: str
    serving: Interval
    version: str

@typing.type_check_only
class Version(typing_extensions.TypedDict, total=False):
    name: str
    version: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleCloudWebriskV1ComputeThreatListDiffResponse(
    typing_extensions.TypedDict, total=False
):
    additions: GoogleCloudWebriskV1ThreatEntryAdditions
    checksum: GoogleCloudWebriskV1ComputeThreatListDiffResponseChecksum
    newVersionToken: str
    recommendedNextDiff: str
    removals: GoogleCloudWebriskV1ThreatEntryRemovals
    responseType: typing_extensions.Literal[
        "RESPONSE_TYPE_UNSPECIFIED", "DIFF", "RESET"
    ]

@typing.type_check_only
class GoogleCloudWebriskV1ComputeThreatListDiffResponseChecksum(
    typing_extensions.TypedDict, total=False
):
    sha256: str

@typing.type_check_only
class GoogleCloudWebriskV1RawHashes(typing_extensions.TypedDict, total=False):
    prefixSize: int
    rawHashes: str

@typing.type_check_only
class GoogleCloudWebriskV1RawIndices(typing_extensions.TypedDict, total=False):
    indices: _list[int]

@typing.type_check_only
class GoogleCloudWebriskV1RiceDeltaEncoding(typing_extensions.TypedDict, total=False):
    encodedData: str
    entryCount: int
    firstValue: str
    riceParameter: int

@typing.type_check_only
class GoogleCloudWebriskV1SearchHashesResponse(
    typing_extensions.TypedDict, total=False
):
    negativeExpireTime: str
    threats: _list[GoogleCloudWebriskV1SearchHashesResponseThreatHash]

@typing.type_check_only
class GoogleCloudWebriskV1SearchHashesResponseThreatHash(
    typing_extensions.TypedDict, total=False
):
    expireTime: str
    hash: str
    threatTypes: _list[str]

@typing.type_check_only
class GoogleCloudWebriskV1SearchUrisResponse(typing_extensions.TypedDict, total=False):
    threat: GoogleCloudWebriskV1SearchUrisResponseThreatUri

@typing.type_check_only
class GoogleCloudWebriskV1SearchUrisResponseThreatUri(
    typing_extensions.TypedDict, total=False
):
    expireTime: str
    threatTypes: _list[str]

@typing.type_check_only
class GoogleCloudWebriskV1Submission(typing_extensions.TypedDict, total=False):
    threatTypes: _list[str]
    uri: str

@typing.type_check_only
class GoogleCloudWebriskV1SubmitUriMetadata(typing_extensions.TypedDict, total=False):
    createTime: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "RUNNING", "SUCCEEDED", "CANCELLED", "FAILED", "CLOSED"
    ]
    updateTime: str

@typing.type_check_only
class GoogleCloudWebriskV1SubmitUriRequest(typing_extensions.TypedDict, total=False):
    submission: GoogleCloudWebriskV1Submission

@typing.type_check_only
class GoogleCloudWebriskV1ThreatEntryAdditions(
    typing_extensions.TypedDict, total=False
):
    rawHashes: _list[GoogleCloudWebriskV1RawHashes]
    riceHashes: GoogleCloudWebriskV1RiceDeltaEncoding

@typing.type_check_only
class GoogleCloudWebriskV1ThreatEntryRemovals(typing_extensions.TypedDict, total=False):
    rawIndices: GoogleCloudWebriskV1RawIndices
    riceIndices: GoogleCloudWebriskV1RiceDeltaEncoding

@typing.type_check_only
class GoogleLongrunningCancelOperationRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleLongrunningListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[GoogleLongrunningOperation]

@typing.type_check_only
class GoogleLongrunningOperation(typing_extensions.TypedDict, total=False):
    done: bool
    error: GoogleRpcStatus
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class GoogleProtobufEmpty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GoogleRpcStatus(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str
